import {Component} from '@angular/core'
import {Observable} from 'rxjs'
import {EmployeeService} from '../../services/employee.service'
import {Employee, EmployeePermission} from '../../../shared/model/employee'
import {takeUntil} from 'rxjs/operators'
import {AccountService} from '../../../accounts/services/account.service'
import {animate, state, style, transition, trigger} from '@angular/animations'
import {ErrorHandlingComponent} from '../../../shared/components/subscribing.component'
import {ActivatedRoute, Router} from '@angular/router'
import {ErrorService} from '../../../shared/service/error.service'

@Component({
  selector: 'cre-employees',
  templateUrl: './list.component.html',
  styleUrls: ['./list.component.sass'],
  animations: [
    trigger('detailExpand', [
      state('collapsed', style({height: '0px', minHeight: '0'})),
      state('expanded', style({height: '*'})),
      transition('expanded <=> collapsed', animate('225ms cubic-bezier(0.4, 0.0, 0.2, 1)'))
    ])
  ]
})
export class ListComponent extends ErrorHandlingComponent {
  employees$: Observable<Employee[]>
  columns = [
    {def: 'id', title: 'Numéro d\'employé', valueFn: e => e.id},
    {def: 'name', title: 'Nom', valueFn: e => `${e.firstName} ${e.lastName}`},
    {def: 'group', title: 'Groupe', valueFn: e => e.group ? e.group.name : 'Aucun'},
    {def: 'permissionCount', title: 'Nombre de permissions', valueFn: e => e.permissions.length},
    {def: 'lastLogin', title: 'Dernière connexion', valueFn: e => e.lastLoginTime ? this.getDate(e.lastLoginTime).toLocaleString() : 'Jamais'}
  ]
  buttons = [{
    text: 'Modifier',
    linkFn: employee => `/employee/edit/${employee.id}`,
    permission: EmployeePermission.EDIT_EMPLOYEE
  }, {
    text: 'Modifier mot de passe',
    linkFn: employee => `/employee/password/edit/${employee.id}`,
    permission: EmployeePermission.EDIT_EMPLOYEE_PASSWORD
  }]

  constructor(
    private employeeService: EmployeeService,
    private accountService: AccountService,
    errorService: ErrorService,
    router: Router,
    activatedRoute: ActivatedRoute
  ) {
    super(errorService, activatedRoute, router)
  }

  ngOnInit(): void {
    this.employees$ = this.employeeService.all.pipe(takeUntil(this.destroy$))
  }

  getDate(dateString: string) {
    return new Date(dateString)
  }
}
